==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24StyledViewFactory.h <==
// class javax.swing.text.StyledEditorKit$StyledViewFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1a33bf2d417a6521 javax_swing_text_StyledEditorKit__24StyledViewFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24StyledViewFactory_H_
#define _JC_javax_swing_text_StyledEditorKit__24StyledViewFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *);

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods	javax_swing_text_StyledEditorKit__24StyledViewFactory;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs {
    _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs	javax_swing_text_StyledEditorKit__24StyledViewFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledViewFactory;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object {
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24StyledViewFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24StyledViewFactory_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StyledEditorKit__24StyledViewFactory.h <==
// class javax.swing.text.StyledEditorKit$StyledViewFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1a33bf2d417a6521 javax_swing_text_StyledEditorKit__24StyledViewFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24StyledViewFactory_H_
#define _JC_javax_swing_text_StyledEditorKit__24StyledViewFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vmethods	javax_swing_text_StyledEditorKit__24StyledViewFactory;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs {
    _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_refs	javax_swing_text_StyledEditorKit__24StyledViewFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledViewFactory;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object {
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24StyledViewFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24StyledViewFactory_H_ */
